pub struct BinningScheme {
pub scheme: Scheme,
}Expand description
Angular binning scheme for scattering calculations.
Defines how to discretize the scattering sphere into angular bins for Mueller matrix and amplitude computations. Supports simple regular grids, custom intervals, and arbitrary bin arrangements.
Fields
scheme: SchemeTrait Implementations
Sourceimpl Clone for BinningScheme
impl Clone for BinningScheme
Sourcefn clone(&self) -> BinningScheme
fn clone(&self) -> BinningScheme
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BinningScheme
impl Debug for BinningScheme
impl DerefToPyAny for BinningScheme
Sourceimpl<'de> Deserialize<'de> for BinningScheme
impl<'de> Deserialize<'de> for BinningScheme
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl ExtractPyClassWithClone for BinningScheme
Sourceimpl<'py> IntoPyObject<'py> for BinningScheme
impl<'py> IntoPyObject<'py> for BinningScheme
Sourcetype Target = BinningScheme
type Target = BinningScheme
The Python output type
Sourcetype Output = Bound<'py, <BinningScheme as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <BinningScheme as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PartialEq for BinningScheme
impl PartialEq for BinningScheme
Sourceimpl PyClass for BinningScheme
impl PyClass for BinningScheme
Sourceimpl PyClassImpl for BinningScheme
impl PyClassImpl for BinningScheme
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = /// Angular binning scheme for scattering calculations.
///
/// Defines how to discretize the scattering sphere into angular bins
/// for Mueller matrix and amplitude computations. Supports simple
/// regular grids, custom intervals, and arbitrary bin arrangements.
const RAW_DOC: &'static CStr = /// Angular binning scheme for scattering calculations. /// /// Defines how to discretize the scattering sphere into angular bins /// for Mueller matrix and amplitude computations. Supports simple /// regular grids, custom intervals, and arbitrary bin arrangements.
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<BinningScheme>
type ThreadChecker = SendablePyClass<BinningScheme>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for BinningScheme
impl PyClassNewTextSignature for BinningScheme
const TEXT_SIGNATURE: &'static str = "(bins)"
Sourceimpl PyMethods<BinningScheme> for PyClassImplCollector<BinningScheme>
impl PyMethods<BinningScheme> for PyClassImplCollector<BinningScheme>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for BinningScheme
impl PyTypeInfo for BinningScheme
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
Sourceimpl Serialize for BinningScheme
impl Serialize for BinningScheme
impl StructuralPartialEq for BinningScheme